The files in this directory contain robotframework-tidy and the needed deps.

To update, erase it and run:

pip install robotframework-tidy --target .

Then:
- remove bin
- remove robot framework
- commit the code
- Verify if the license brought in from the libraries downloaded are OK


This folder should be automatically added to the PYTHONPATH when needed.